pub struct GitLabMcpHandler { /* private fields */ }Expand description
GitLab MCP server handler
Implementations
Sourceimpl GitLabMcpHandler
impl GitLabMcpHandler
Sourcepub fn new(
config: &AppConfig,
gitlab: GitLabClient,
access: AccessResolver,
) -> Self
pub fn new( config: &AppConfig, gitlab: GitLabClient, access: AccessResolver, ) -> Self
Create a new handler from configuration
Create a new handler with shared (Arc-wrapped) resources
This is useful when creating multiple handlers that share the same GitLab client and access resolver (e.g., for HTTP transport with multiple concurrent connections).
Sourcepub fn new_with_metrics(
config: &AppConfig,
gitlab: Arc<GitLabClient>,
access: Arc<AccessResolver>,
metrics: Arc<DashboardMetrics>,
) -> Self
pub fn new_with_metrics( config: &AppConfig, gitlab: Arc<GitLabClient>, access: Arc<AccessResolver>, metrics: Arc<DashboardMetrics>, ) -> Self
Create a new handler with shared resources and metrics
Sourcepub fn tool_count(&self) -> usize
pub fn tool_count(&self) -> usize
Get the number of registered tools